@@ -4,8 +4,7 @@
 ##'
 ##' @name logLik
 ##' @rdname loglik
-##' @aliases logLik logLik,ANY-method logLik,missing-method
-##' logLik,listie-method
+##' @aliases logLik,ANY-method logLik,missing-method
 ##' @include pfilter.R wpfilter.R mif2.R pmcmc.R probe.R kalman.R nlf.R listie.R
 ##' @include objfun.R spect_match.R nlf.R
 ##'
@@ -19,12 +18,9 @@
 NULL
 
 ##' @rdname loglik
+##' @importFrom stats logLik
 ##' @export
-setGeneric(
-  "logLik",
-  function (object, ...)
-    standardGeneric("logLik")
-)
+setGeneric("logLik")
 
 setMethod(
   "logLik",
@@ -52,9 +48,9 @@ setMethod(
   }
 )
 
-##' @name logLik-pfilterd_pomp
-##' @aliases logLik,pfilterd_pomp-method
 ##' @rdname loglik
+##' @return
+##' When \code{object} is of \sQuote{pfilterd_pomp} class (i.e., the result of a \code{wpfilter} computation), \code{logLik} retrieves the estimated log likelihood.
 ##' @export
 setMethod(
   "logLik",
@@ -62,9 +58,9 @@ setMethod(
   definition=function(object)object@loglik
 )
 
-##' @name logLik-wpfilterd_pomp
-##' @aliases logLik,wpfilterd_pomp-method
 ##' @rdname loglik
+##' @return
+##' When \code{object} is of \sQuote{wpfilterd_pomp} class (i.e., the result of a \code{wpfilter} computation), \code{logLik} retrieves the estimated log likelihood.
 ##' @export
 setMethod(
   "logLik",
@@ -72,22 +68,19 @@ setMethod(
   definition=function(object)object@loglik
 )
 
-##' @name logLik-probed_pomp
-##' @aliases logLik,probed_pomp-method
 ##' @rdname loglik
-##'
 ##' @return
-##' When \code{object} is of \sQuote{probed_pomp} class (i.e., the result of a \code{probe} computation), \code{logLik} retrieves the \dQuote{synthetic likelihood} (see \code{\link{probe}}).
-##'
+##' When \code{object} is of \sQuote{probed_pomp} class (i.e., the result of a \code{\link{probe}} computation), \code{logLik} retrieves the \dQuote{synthetic likelihood}.
+##' @export
 setMethod(
   "logLik",
   signature=signature(object="probed_pomp"),
   definition=function(object)object@synth.loglik
 )
 
-##' @name logLik-kalmand_pomp
-##' @aliases logLik,kalmand_pomp-method
 ##' @rdname loglik
+##' @return
+##' When \code{object} is of \sQuote{kalmand_pomp} class (i.e., the result of an \code{\link{eakf}} or \code{\link{enkf}} computation), \code{logLik} retrieves the estimated log likelihood.
 ##' @export
 setMethod(
   "logLik",
@@ -95,9 +88,9 @@ setMethod(
   definition=function(object)object@loglik
 )
 
-##' @name logLik-pmcmcd_pomp
-##' @aliases logLik,pmcmcd_pomp-method
 ##' @rdname loglik
+##' @return
+##' When \code{object} is of \sQuote{pmcmcd_pomp} class (i.e., the result of a \code{\link{pmcmc}} computation), \code{logLik} retrieves the estimated log likelihood as of the last particle filter operation.
 ##' @export
 setMethod(
   "logLik",
@@ -106,15 +99,9 @@ setMethod(
     object@loglik
 )
 
-##' @name logLik-bsmcd_pomp
-##' @aliases logLik,bsmcd_pomp-method
 ##' @rdname loglik
-##'
-##' @importFrom stats logLik
-##'
 ##' @return
-##' When \code{object} is of \sQuote{bsmcd_pomp} class (i.e., the result of a \code{bsmc2} computation), \code{logLik} retrieves the \dQuote{log evidence} (see \code{\link{bsmc2}}).
-##'
+##' When \code{object} is of \sQuote{bsmcd_pomp} class (i.e., the result of a \code{\link{bsmc2}} computation), \code{logLik} retrieves the \dQuote{log evidence}.
 ##' @export
 setMethod(
   "logLik",
@@ -122,9 +109,7 @@ setMethod(
   definition=function(object)object@log.evidence
 )
 
-##' @name logLik-objfun
 ##' @rdname loglik
-##' @aliases logLik,objfun-method
 ##' @export
 setMethod(
   "logLik",
@@ -134,9 +119,9 @@ setMethod(
   }
 )
 
-##' @name logLik-spect_match_objfun
 ##' @rdname loglik
-##' @aliases logLik,spect_match_objfun-method
+##' @return
+##' When \code{object} is of \sQuote{spect_match_objfun} class (i.e., an objective function constructed by \code{\link{spect_objfun}}), \code{logLik} retrieves minus the spectrum mismatch.
 ##' @export
 setMethod(
   "logLik",
@@ -146,14 +131,10 @@ setMethod(
   }
 )
 
-##' @name logLik-nlf_objfun
-##' @aliases logLik,nlf_objfun-method
 ##' @rdname loglik
-##'
 ##' @return
-##' When \code{object} is an NLF objective function, i.e., the result of a call to \code{nlf_objfun},
-##' \code{logLik} retrieves the \dQuote{quasi log likelihood} (see \code{\link{nlf}}).
-##'
+##' When \code{object} is an NLF objective function, i.e., the result of a call to \code{\link{nlf_objfun}},
+##' \code{logLik} retrieves the \dQuote{quasi log likelihood}.
 ##' @export
 setMethod(
   "logLik",
