@@ -2,15 +2,10 @@
 ##'
 ##' Display a summary of a fitted model object.
 ##'
-##' @rdname summary
 ##' @name summary
-##'
+##' @rdname summary
 ##' @param object a fitted model object
 ##' @param \dots ignored
 NULL
 
-setGeneric(
-  "summary",
-  function (object, ...)
-    standardGeneric("summary")
-)
+setGeneric("summary")
